//Name:		TetrisResources.cpp
//Author:	Brian Tietz
//Copyright 1999-2000
//Conventions:
//	Global constants (declared with const) and #defines - begin with "c_" followed by lowercase
//		words separated by underscores.
//		(E.G., #define c_my_constant 5).
//		(E.G., const int c_my_constant = 5;).
//	Global variables - begin with "g_" followed by lowercase words separated by underscores.
//		(E.G., int g_my_global;).
//	New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//		lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//		associating them with a particular enumerated set.
//		(E.G., typedef int MyTypedef;).
//		(E.G., enum MyEnumConst {c_mec_one, c_mec_two};)
//	Private member variables - begin with "m_" followed by lowercase words separated by underscores.
//		(E.G., int m_my_member;).
//	Public or friend-accessible member variables - all lowercase words separated by underscores.
//		(E.G., int public_member;).
//	Argument and local variables - begin with a lowercase letter followed by
//		lowercase words separated by underscores.  If the name is already taken by a public member
//		variable, prefix with a_ or l_
//		(E.G., int my_local; int a_my_arg, int l_my_local).
//	Functions (member or global) - begin with an uppercase letter followed by lowercase words
//		separated by uppercase letters.
//		(E.G., void MyFunction(void);).
//License:
//  Obviously, the idea for Tetris isn't mine, so I hold no copyright on the idea.  I do, however,
//  reserve all rights with regard to the source code for this BeOS version of Tetris.  The executable,
//  is freely distributable.  The source code is likewise freely distributable, provided that the
//  license and copyright are retained in these source code files and in the about box of the
//  executable.


//******************************************************************************************************
//**** System header files
//******************************************************************************************************
#include <TranslationUtils.h>
#include <Bitmap.h>
#include <View.h>


//******************************************************************************************************
//**** Project header files
//******************************************************************************************************
#include "TetrisResources.h"


//******************************************************************************************************
//**** Global variable declarations
//******************************************************************************************************
extern Block g_blocks[7];
const Block* c_blocks = g_blocks;


//******************************************************************************************************
//**** TetrisResources
//******************************************************************************************************
TetrisResources::TetrisResources()
{
	m_init_ok = true;
	char bitmap_name[] = "brickN.png";
	for(int i=0; i<7; i++)
	{
		bitmap_name[5] = i+'1';
		if(i == 0)
			strcpy(&bitmap_name[7],"tga");		//Because R4.5 PPC translator doesn't like that particular png
		else
			strcpy(&bitmap_name[7],"png");
		BBitmap* bitmap = BTranslationUtils::GetBitmap(bitmap_name);
		if(bitmap == NULL)
		{
			m_init_ok = false;
			return;
		}
		else if(bitmap->ColorSpace() != B_RGB32)
		{
			BBitmap* bitmap_32 = new BBitmap(bitmap->Bounds(),B_RGB32,true);
			bitmap_32->Lock();
			BView* drawing_view = new BView(bitmap_32->Bounds(),NULL,0,0);
			bitmap_32->AddChild(drawing_view);
			drawing_view->DrawBitmap(bitmap,drawing_view->Bounds());
			delete bitmap;
			bitmap = bitmap_32;
		}
		uint32* data = (uint32*)bitmap->Bits();
		for(int8 x=0; x<16; x++)
			for(int8 y=0; y<16; y++)
				((Block*)g_blocks)[i].bitmap_data[x][y] = data[y*16+x];
		delete bitmap;
	}
}


//******************************************************************************************************
//**** Blocks
//******************************************************************************************************
Block g_blocks[7] =
{
	{{{{0,0,0,0},
	   {0,0,0,0},
	   {1,1,1,1},
	   {0,0,0,0}},
	  {{0,0,1,0},
	   {0,0,1,0},
	   {0,0,1,0},
	   {0,0,1,0}},
	  {{0,0,0,0},
	   {0,0,0,0},
	   {1,1,1,1},
	   {0,0,0,0}},
	  {{0,0,1,0},
	   {0,0,1,0},
	   {0,0,1,0},
	   {0,0,1,0}}},{0}},

	{{{{0,0,0,0},
	   {0,1,1,0},
	   {0,1,1,0},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,1,1,0},
	   {0,1,1,0},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,1,1,0},
	   {0,1,1,0},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,1,1,0},
	   {0,1,1,0},
	   {0,0,0,0}}},{0}},

	{{{{0,0,0,0},
	   {0,0,1,0},
	   {0,1,1,0},
	   {0,0,1,0}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,1,1,1},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,0,1,1},
	   {0,0,1,0}},
	  {{0,0,0,0},
	   {0,0,0,0},
	   {0,1,1,1},
	   {0,0,1,0}}},{0}},

	{{{{0,0,0,0},
	   {0,0,0,0},
	   {0,0,1,1},
	   {0,1,1,0}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,0,1,1},
	   {0,0,0,1}},
	  {{0,0,0,0},
	   {0,0,0,0},
	   {0,0,1,1},
	   {0,1,1,0}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,0,1,1},
	   {0,0,0,1}}},{0}},

	{{{{0,0,0,0},
	   {0,1,1,0},
	   {0,0,1,1},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,0,0,1},
	   {0,0,1,1},
	   {0,0,1,0}},
	  {{0,0,0,0},
	   {0,1,1,0},
	   {0,0,1,1},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,0,0,1},
	   {0,0,1,1},
	   {0,0,1,0}}},{0}},

	{{{{0,0,0,0},
	   {0,0,0,0},
	   {0,1,1,1},
	   {0,0,0,1}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,0,1,0},
	   {0,1,1,0}},
	  {{0,0,0,0},
	   {0,1,0,0},
	   {0,1,1,1},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,0,1,1},
	   {0,0,1,0},
	   {0,0,1,0}}},{0}},

	{{{{0,0,0,0},
	   {0,0,0,1},
	   {0,1,1,1},
	   {0,0,0,0}},
	  {{0,0,0,0},
	   {0,0,1,0},
	   {0,0,1,0},
	   {0,0,1,1}},
	  {{0,0,0,0},
	   {0,0,0,0},
	   {0,1,1,1},
	   {0,1,0,0}},
	  {{0,0,0,0},
	   {0,1,1,0},
	   {0,0,1,0},
	   {0,0,1,0}}},{0}}
};

